UpdateShapeCommand<T> class

Command that replaces one shape with another (e.g. vertex edit).

Inheritance

Constructors

UpdateShapeCommand({required List<T> shapes, required T oldShape, required T newShape, required bool matcher(T a, T b)})

Properties

description String
Human-readable description of this command.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() → void
Execute (or re-execute) the command.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
undo() → void
Reverse the command.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited