DrawablePolyline class
- Inheritance
-
- Object
- DrawableShape
- DrawablePolyline
Constructors
-
DrawablePolyline({required String id, required List<
LatLng> points, ShapeStyle style = const ShapeStyle(), Map<String, dynamic> metadata = const {}}) -
const
-
DrawablePolyline.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allPoints
→ List<
LatLng> -
All points that define this shape's geometry.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier (UUID).
finalinherited
-
metadata
→ Map<
String, dynamic> -
Arbitrary user metadata (tags, names, etc.).
finalinherited
-
points
→ List<
LatLng> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ShapeStyle
-
Visual style.
finalinherited
- type → ShapeType
-
The type discriminator for serialization.
no setteroverride
Methods
-
copyWith(
{String? id, List< LatLng> ? points, ShapeStyle? style, Map<String, dynamic> ? metadata}) → DrawablePolyline -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited